import glpk

print "starting..."
example = glpk.glpk("example.mod")
example.solve()
print "solution:", example.sol
print "solution is also here:", example.x
